==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/pl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Zarządzaj Parametry Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Zarządzaj Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Powieksz zdjecie Szerokość");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Wysokość obrazu");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Szerokość obrazu");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Wysokość");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Kciuk Zachowaj proporcje");
define('MANAGE_GALLERY_SHOW_TITLES', "Pokaż Tytuły");
define('MANAGE_GALLERY_DISABLE_SORT', "Wyłącz Sortuj");
define('MANAGE_GALLERY_DELETE_IMAGE', "Usuń obraz");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Zapisz Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknij przycisk &quot;Update&quot;, aby opublikować <br /> Twoje załadowane zdjęcia.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Wszystkie obrazy zostały przeskalowane i ustawienia zostały zapisane.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Wystąpił błąd podczas zmiany rozmiaru obrazów lub zapisywania ustawień.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Twój obraz (y) został przesłany.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Wystąpił błąd podczas przesyłania obrazu (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Plik, który próbujesz przesłać nie jest obraz.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Plik, który próbujesz przesłać jest zbyt duży.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tytuł został zapisany.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Czy na pewno chcesz usunąć zdjęcie");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz został usunięty.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Wystąpił błąd podczas kasowania zdjęcia.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Zapisywanie parametrów i zmiana rozmiaru obrazów, proszę czekać ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Przekazywanie, proszę czekać ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Kolejność sortowania nie został zapisany. Czy chcesz zapisać porządek?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Kolejność sortowania obraz został zapisany.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Wystąpił błąd podczas zapisywania rodzaju obrazu.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/pl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Zarządzaj Parametry Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Zarządzaj Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Powieksz zdjecie Szerokość");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Wysokość obrazu");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Szerokość obrazu");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Wysokość");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Kciuk Zachowaj proporcje");
define('MANAGE_GALLERY_SHOW_TITLES', "Pokaż Tytuły");
define('MANAGE_GALLERY_DISABLE_SORT', "Wyłącz Sortuj");
define('MANAGE_GALLERY_DELETE_IMAGE', "Usuń obraz");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Zapisz Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknij przycisk &quot;Update&quot;, aby opublikować <br /> Twoje załadowane zdjęcia.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Wszystkie obrazy zostały przeskalowane i ustawienia zostały zapisane.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Wystąpił błąd podczas zmiany rozmiaru obrazów lub zapisywania ustawień.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Twój obraz (y) został przesłany.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Wystąpił błąd podczas przesyłania obrazu (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Plik, który próbujesz przesłać nie jest obraz.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Plik, który próbujesz przesłać jest zbyt duży.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tytuł został zapisany.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Czy na pewno chcesz usunąć zdjęcie");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz został usunięty.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Wystąpił błąd podczas kasowania zdjęcia.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Zapisywanie parametrów i zmiana rozmiaru obrazów, proszę czekać ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Przekazywanie, proszę czekać ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Kolejność sortowania nie został zapisany. Czy chcesz zapisać porządek?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Kolejność sortowania obraz został zapisany.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Wystąpił błąd podczas zapisywania rodzaju obrazu.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Plik, który próbujesz przesłać, jest większy niż ustawienia PHP „upload_max_filesize” lub „post_max_size”. Skontaktuj się z administratorem systemu, aby zwiększyć te limity.");
?>
